(* Js_of_ocaml library
 * http://www.ocsigen.org/js_of_ocaml/
 * Copyright (C) 2017 Hugo Heuzard
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, with linking exception;
 * either version 2.1 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *)

module CSS = CSS
module Console = Console
module Dom = Dom
module Dom_events = Dom_events
module Dom_html = Dom_html
module Dom_svg = Dom_svg
module Effect_js = Effect_js
module EventSource = EventSource
module File = File
module Firebug = Console
[@@ocaml.deprecated "[since 6.0] Use Js_of_ocaml.Console instead."]
module Form = Form
module Geolocation = Geolocation
module IntersectionObserver = IntersectionObserver
module Intl = Intl
module Js = Js
module Js_error = Js.Js_error
module Json = Json
module Jstable = Jstable
module MutationObserver = MutationObserver
module PerformanceObserver = PerformanceObserver
module ResizeObserver = ResizeObserver
module Regexp = Regexp
module Sys_js = Sys_js
module Typed_array = Typed_array
module Url = Url
module WebGL = WebGL
module WebSockets = WebSockets
module Worker = Worker
module XmlHttpRequest = XmlHttpRequest
